@@ -28,7 +28,7 @@ class MemoFormlet {
       $url = "index.php?mod=Home#Memo";
     }
     else {
-      $url = "index.php?mod=FormletLauncher&amp;formlet=Memo#Memo";
+      $url = "index.php?mod=FormletLauncher&formlet=Memo#Memo";
     }
     redirect_to($url, '񤭹ߤޤ', 0);
   }
