@@ -6,7 +6,8 @@ function fwrite_safe($name, $text) {
   fwrite($tmpfp, $text, strlen($text));
   fflush($tmpfp);
   fclose($tmpfp);
-  unlink($name) && rename($tmp, $name);
+  if (file_exists($name)) unlink($name);
+  if (!file_exists($name)) rename($tmp, $name);
   chmod($name, 0666);
 }
 
@@ -36,6 +37,20 @@ class WikiPageStorage {
       WikiPageStorage::putAge($name, $text, $memo);
   }
 
+  function remove($name) {
+    if (WikiPageStorage::pageExists($name)) {
+      $path = WikiPageStorage::filePath($name);
+      unlink($path);
+      //propertyɬפʹܤunset
+      //diff, edit_memo, last_modified_user, creator
+      $property = Property::instance();
+      $property->unsetKey($name, 'diff');
+      $property->unsetKey($name, 'edit_memo');
+      $property->unsetKey($name, 'last_modified_user');
+      $property->unsetKey($name, 'creator');
+    }
+  }
+
   function pageExists($name) {
     return file_exists(WikiPageStorage::filePath($name));
   }
@@ -85,7 +100,7 @@ class WikiPageStorage {
     foreach ($lines as $line) {
       rtrim($line);
       if (preg_match("/\t/", $line)) {
-				list($timestamp, $user, $memo) = split("\t", $line);
+        list($timestamp, $user, $memo) = split("\t", $line);
       }
       else {
         // mature history data occured.
@@ -323,12 +338,20 @@ class WikiCommentStorage {
   function appendComment($comment, $page) {
     $path = WikiCommentStorage::filePath($page);
     $fp = fopen($path, "a") or die("comment file open error");
-    $comment->escape();
     fwrite($fp, serialize($comment)."\n");
     fflush($fp);
     fclose($fp);
   }
 
+  function remove($page) {
+    if (WikiCommentStorage::exists($page)) {
+      $path = WikiCommentStorage::filePath($page);
+      unlink($path);
+      $property = Property::instance();
+      $property->unsetKey($page, 'last_commented_user');
+    }
+  }
+
   function filePath($name) {
     $encoded = urlencode($name);
     $basename = basename($encoded, ".cmt");
@@ -398,15 +421,16 @@ class HashDB {
       $this->init();
     }
   }
+
   function init() {
-    $fp = fopen($this->path, "w") or die("database initialization error");
-    fflush($fp);
-    fclose($fp);
+    touch($this->path) or die("database initialization error");
   }
+
   function exists($key) {
     $this->begin();
     return isset($this->hash[$key]);
   }
+
   function insert($key, $val) {
     $this->begin();
     if ($this->exists($key)) { return false; }
@@ -414,6 +438,7 @@ class HashDB {
     $this->commit();
     return true;
   }
+
   function update($key, $val) {
     $this->begin();
     if (!$this->exists($key)) return false;
@@ -421,14 +446,17 @@ class HashDB {
     $this->commit();
     return true;
   }
+
   function fetch($key) {
     $this->begin();
     return $this->hash[$key];
   }
+
   function keys() {
     $this->begin();
     return array_keys($this->hash);
   }
+
   function delete($key) {
     $this->begin();
     if (!$this->exists($key)) return false;
@@ -439,7 +467,8 @@ class HashDB {
 
   function begin() {
     clearstatcache();
-    if (file_exists($this->path)) {
+    file_exists($this->path) or die("error: database " . $this->path . " is not exists.");
+    if (filesize($this->path) > 0) {
       $fp = fopen($this->path, "r");
       $buf = fread($fp, filesize($this->path));
       fclose($fp);
@@ -447,7 +476,7 @@ class HashDB {
     else {
       $buf = '';
     }
-    if (strlen($buf)) $hash = unserialize($buf);
+    if (strlen($buf) > 0) $hash = unserialize($buf);
     else $hash = array();
     $this->hash = $hash;
   }
@@ -533,6 +562,18 @@ class Property {
       $this->db->insert($page, $hash);
     }
   }
+
+  function unsetKey($page, $key) {
+    if ($this->db->exists($page)) {
+      $hash = $this->db->fetch($page);
+      unset($hash[$key]);
+      $this->db->update($page, $hash);
+    }
+  }
+
+  function delete($page) {
+    $this->db->delete($page);
+  }
 }
 
 class Queue {
