@@ -6,10 +6,7 @@
 </div>
 
 <h1><?php echo htmlspecialchars(SITE_NAME) ?> - <?php echo htmlspecialchars(SITE_SUBTITLE) ?></h1>
-<?php if (!WebSession::isLogined()): ?>
-  <p>桼ϿϤѤߤǤ<br>
-  ޤϿڡ<a href="index.php?mod=Account">Go!</a></p>
-<?php endif; ?>
+
 <?php
 $formatter = new Formatter();
 
@@ -20,7 +17,6 @@ else:
   echo "<p>", $formatter->format(WikiPageStorage::get(WELCOME_VISITORS)), "</p>";
   include "template/RecentList.tmpl.php";
 ?>
-
  <h2>Ͽ桼̾</h2>
  <?php AccountListFormlet::show() ?>
 <?php
